#!/bin/bash
#set -vx
# Default options
#
#
#
#### 1  Set up the compiling options
#### Define some directories
submitdir=$( pwd )
modipsl=$submitdir/../..
echo modipsl=$modipsl 
echo submitdir=$submitdir
arch_path=$modipsl/modeles/ARCH 
export ROOT=$modipsl/modeles/DYNAMICO

#### 1.1 Set default options 
# Optimization mode
# optmode=prod/dev/debug
optmode=prod
# Resolution if compiling LMDZ in regular mode without DYNAMICO
regular_latlon=no
# fcm_arch
fcm_arch=default
# Default values to be overritten
parallel=mpi
export fcm_arch parallel xios
full_flag=""

#### 1.2 Read arguments 
# Loop over all arguments to modify default set up
while (($# > 0)) ; do
case $1 in
"-h") cat <<fin

########################################################################
# Usage of the script compile_config
#
########################################################################

./compile_config [Options] 

Options
....

Example 1 : ...
...

fin
exit;;

"-parallel")
parallel=$2 ; shift ; shift ;; 
               
"-arch")
fcm_arch="$2" ; shift ; shift ;;

"-xios")
xios="$2" ; shift ; shift ;;

"-optmode")
optmode=$2 ; shift ; shift ;;

"-regular_latlon")
regular_latlon=$2 ; shift ; shift ;;

"-full")
full_flag="-full"; shift ;;
*)
echo "unknown option "$2" , exiting..."
exit 
esac
done
echo full_flag=$full_flag

### 1.3 Read host dependent default values
###     These variables will not be changed if they were set as argument
###./host.sh $host
# Later : Following lines should be set in host.sh file
# begin host.sh
if [ $fcm_arch == default ] ; then
# Find out current host and source specific paths and commands for the host
case $( hostname -s ) in
ada*)
fcm_arch=X64_ADA;;
irene*)
fcm_arch=X64_IRENE;
source /ccc/cont003/home/igcmg/igcmg/MachineEnvironment/irene/env_irene ;;
asterix*|obelix*)
fcm_arch=ifort_LSCE;;
*)
echo Current host is not known. You must use option -fcm_arch to specify which architecuture files to use.
echo Exit now.
exit
esac
fi

##### End host.sh
echo
echo Following arguments are set in current compiling:
echo "   optmode = $optmode, parallel = $parallel, fcm_arch = $fcm_arch, full_flag=$full regular_latlon=$regular_latlon"

#### 2 Do the compilation 
## 2.1 Compile ioipsl
cd $modipsl/modeles/IOIPSL
echo; echo NOW COMPILE IOIPSL
echo ./makeioipsl_fcm -$optmode -parallel -arch ${fcm_arch} -arch_path $arch_path -j 8 $full_flag
./makeioipsl_fcm -$optmode -parallel -arch ${fcm_arch} -arch_path $arch_path -j 8 $full_flag
# Test if compiling succeded 
if [[ $? != 0 ]] ; then 
  echo "THERE IS A PROBLEM IN IOIPSL COMPILATION - STOP"
  exit
fi

## 2.2 Compile xios
cd $modipsl/modeles/XIOS
echo; echo NOW COMPILE XIOS
echo ./make_xios --$optmode --arch $fcm_arch --arch_path $arch_path --job 8 $full_flag
./make_xios --$optmode --arch $fcm_arch --arch_path $arch_path --job 8 $full_flag
# Test if compiling succeded 
if [[ $? != 0 ]] ; then 
  echo "THERE IS A PROBLEM IN XIOS COMPILATION - STOP"
  exit
fi

## 2.3 Compile orchidee
cd $modipsl/modeles/ORCHIDEE
echo; echo NOW COMPILE ORCHIDEE
echo 	./makeorchidee_fcm -j 8 -parallel $parallel -$optmode -arch ${fcm_arch} $full_flag -driver
./makeorchidee_fcm -j 8 -parallel $parallel -$optmode -arch ${fcm_arch} $full_flag -driver
# Test if compiling finished
if [[ $? != 0 ]] ; then
    echo "THERE IS A PROBLEM IN ORCHIDEE COMPILATION - STOP"
    exit
fi


## 2.5 Compile lmdz
cd $modipsl/modeles/LMDZ
if [ ${regular_latlon} = no ] ; then
    # Compile as library to couple to DYNAMICO
    echo; echo NOW COMPILE LMDZ FOR COUPLING TO DYNAMICO
    echo ./makelmdz_fcm -p lmd -rrtm true -$optmode -mem -parallel $parallel -libphy -v orchidee2.1 -io xios -arch $fcm_arch -j 8 $full_flag
    ./makelmdz_fcm -p lmd -rrtm true -$optmode -mem -parallel $parallel -libphy -v orchidee2.1 -io xios -arch $fcm_arch -j 8 $full_flag
else
    # Compile regular lat-lon exectuable
    echo; echo NOW COMPILE LMDZ REGULAR LAT-LON MODE. Resolution = ${regular_latlon}
    echo ./makelmdz_fcm -d ${regular_latlon} -p lmd -rrtm true -$optmode -mem -parallel $parallel -io xios -v orchidee2.1 -arch $fcm_arch -arch_path $arch_path -j 8 $full_flag gcm
    ./makelmdz_fcm -d ${regular_latlon} -p lmd -rrtm true -$optmode -mem -parallel $parallel -io xios -v orchidee2.1 -arch $fcm_arch -arch_path $arch_path -j 8 $full_flag gcm
fi

# Test if compiling finished
if [[ $? != 0 ]] ; then
    echo "THERE IS A PROBLEM IN LMDZ COMPILATION - STOP"
    exit
fi

# Compile DYNAMICO
echo; echo NOW COMPILE DYNAMICO 
cd $modipsl/modeles/DYNAMICO
echo ./make_icosa -$optmode -parallel $parallel -external_ioipsl -with_xios -arch $fcm_arch -arch_path $arch_path -job 8 $full_flag
./make_icosa -$optmode -parallel $parallel -external_ioipsl -with_xios -arch $fcm_arch -arch_path $arch_path -job 8 $full_flag
# Test if compiling finished
if [[ $? != 0 ]] ; then
  echo "THERE IS A PROBLEM IN DYNAMICO COMPILATION - STOP"
  exit
fi

# Compile interface ICOSA_LMDZ
echo; echo NOW COMPILE ICOSA_LMDZ 
cd $modipsl/modeles/ICOSA_LMDZ
echo ./make_icosa_lmdz -nodeps -$optmode -parallel $parallel -with_orchidee -arch ${fcm_arch} -arch_path ${arch_path} -job 8 $full_flag

./make_icosa_lmdz -nodeps -$optmode -parallel $parallel -with_orchidee -arch ${fcm_arch} -arch_path ${arch_path} -job 8 $full_flag
# Test if compiling finished
if [[ $? != 0 ]] ; then
  echo "THERE IS A PROBLEM IN ICOSA_LMDZ COMPILATION - STOP"
  exit
fi

# Move executables to modipsl/bin folder
echo "Move executables to modipsl/bin"
if [ $modipsl/modeles/ICOSA_LMDZ/bin/icosa_lmdz.exe ] ; then mv $modipsl/modeles/ICOSA_LMDZ/bin/icosa_lmdz.exe $modipsl/bin/. ; fi
if [ $modipsl/modeles/XIOS/bin/xios_server.exe ] ; then mv $modipsl/modeles/XIOS/bin/xios_server.exe $modipsl/bin/. ; fi


# Write resolution into .resol file
if [ $regular_latlon != no ] ; then
    # Copy executable
# Find executable suffix 
if [ $parallel == seq ] || [ $parallel == none ] ; then
    suffix=_seq
else
    suffix=_para
fi
suffix=${suffix}_orch
echo suffix = $suffix
    

    # Write .resol file
    cd $submitdir   
    resol2D=$( echo ${regular_latlon} | awk '-Fx' '{print $1}' )$( echo ${regular_latlon} | awk '-Fx' '{print $2}' )
    echo "noORCAxLMD$resol2D" >.resol
    echo "RESOL_ATM_3D=${regular_latlon}" >>.resol
fi

echo 
echo ALL COMPILING FINISHED
echo
exit


